#
# spec file for package python-flake8
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-flake8
Version:        3.7.7
Release:        1.12
Summary:        Modular source code checker: pep8, pyflakes and co
License:        MIT
Group:          Development/Languages/Python
URL:            https://gitlab.com/pycqa/flake8
Source:         https://files.pythonhosted.org/packages/source/f/flake8/flake8-%{version}.tar.gz
Patch0:         remove_mock_dependency.patch
Patch1:         fix-mock-patch-with-python3.4.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-entrypoints >= 0.3
Requires:       python-mccabe >= 0.6.0
Requires:       python-pycodestyle >= 2.5.0
Requires:       python-pyflakes >= 2.1.0
Requires:       python-typing
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module entrypoints >= 0.3}
BuildRequires:  %{python_module mccabe >= 0.6.0}
BuildRequires:  %{python_module pycodestyle >= 2.5.0}
BuildRequires:  %{python_module pyflakes >= 2.1.0}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing}
%if %{with python2}
BuildRequires:  python2-configparser >= 3.7.0
BuildRequires:  python2-enum34
BuildRequires:  python2-functools32
BuildRequires:  python2-mock
%endif
# /SECTION
%ifpython2
Requires:       python-configparser >= 3.7.0
Requires:       python-enum34
Requires:       python-functools32
%endif
%python_subpackages

%description
Flake8 is a modular extensible source code checker including wrappers
around these tools:

- PyFlakes
- pep8
- Ned Batchelder's McCabe script

Flake8 runs all the tools by launching the single ``flake8`` script.

%package -n %{name}-doc
Summary:        Documentation files for %name
Group:          Documentation/Other
Recommends:     %{name} = %{version}

%description -n %{name}-doc
Flake8 is a modular extensible source code checker.

This package provides documentation for %{name}.

%prep
%setup -q -n flake8-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/flake8
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative flake8

%postun
%python_uninstall_alternative flake8

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python -m pytest tests

%files %{python_files}
%license LICENSE
%doc docs/source/manpage.rst
%python_alternative %{_bindir}/flake8
%dir %{python_sitelib}/flake8
%{python_sitelib}/flake8/*
%{python_sitelib}/flake8-%{version}-py*.egg-info

%files -n %{name}-doc
%doc README.rst
%doc docs/source/index.rst docs/source/faq.rst docs/source/glossary.rst
%doc docs/source/internal/ docs/source/user docs/source/plugin-development
%license LICENSE

%changelog
* Sun Mar  3 2019 jayvdb@gmail.com
- Create doc sub package with rst files, and README.rst
- Replace main package %%doc README.rst with manpage.rst
- Simplify dependency on python-typing, which is provided by
  python3-base when it isnt a separate dependency
* Sat Mar  2 2019 arun@gmx.de
- update to version 3.7.7:
  * Fix crahes in plugins causing flake8 to hang while unpickling
    errors (See also GitLab!308, GitLab#505)
* Thu Feb 21 2019 jayvdb@gmail.com
- Update to v3.7.6
  * Fix ``--per-file-ignores`` for multi-letter error codes
  * Improve flake8 speed when only 1 filename is passed
* Wed Feb  6 2019 alarrosa@suse.com
- Add missing dependency on python3-typing when python3 < 3.5
- Add fix-mock-patch-with-python3.4.patch to fix building the package in
  Leap 42.3. In python 3.5, mock.patch uses create=True automatically if
  you are patching builtins in a module, but in python 3.4 the argument
  is still needed.
* Tue Feb  5 2019 alarrosa@suse.com
- Enable tests
- Add allow-bytes-filenames.patch to fix some tests that fail because
  they pass bytes objects as filenames.
- Update remove_mock_dependency.patch to fix another test that used mock
* Tue Feb  5 2019 alarrosa@suse.com
- Update to version 3.7.5:
  * Bugs Fixed
    + Fix reporting of pyflakes "referenced before assignment" error
    (See also GitLab!301, GitLab#503)
- Update to version 3.7.4:
  * Bugs Fixed
    + Fix performance regression with lots of per-file-ignores and errors
    (See also GitLab!299, GitLab#501)
- Update to version 3.7.3:
  * Bugs Fixed
    + Fix imports of typing in python 3.5.0 / 3.5.1 (See also GitLab!294,
    GitLab#498)
    + Fix flake8 --statistics (See also GitLab!295, GitLab#499)
    + Gracefully ignore flake8-per-file-ignores plugin if installed
    (See also GitLab!297, GitLab#495)
    + Improve error message for malformed per-file-ignores
    (See also GitLab!298, GitLab#489)
- Update to version 3.7.2:
  * Bugs Fixed
    + Fix broken flake8 --diff (regressed in 3.7.0) (See also GitLab!292,
    GitLab#490)
    + Fix typo in plugin exception reporting (See also GitLab!275, GitLab#491)
    + Fix AttributeError while attempting to use the legacy api
    (regressed in 3.7.0) (See also GitLab!293, GitLab#497)
- Update to version 3.7.1:
  * Bugs Fixed
    + Fix capitalized filenames in per-file-ignores setting (See also GitLab!290, GitLab#488)
- Update to version 3.7.0:
  * New Dependency Information
    + Add dependency on entrypoints >= 0.3, < 0.4
    (See also GitLab!264, GitLab!288)
    + Pyflakes has been updated to >= 2.1.0, < 2.2.0
    (See also GitLab!283, GitLab!285)
    + pycodestyle has been updated to >= 2.5.0, < 2.6.0
    (See also GitLab!287)
  * Features
    + Add support for per-file-ignores (See also GitLab!259, GitLab#156,
    GitLab!281, GitLab#471)
    + Enable use of float and complex option types (See also GitLab!261,
    GitLab#452)
    + Improve startup performance by switching from pkg_resources to
    entrypoints (See also GitLab!264)
    + Add metadata for use through the pre-commit git hooks framework
    (See also GitLab!268, GitLab!284)
    + Allow physical line checks to return more than one result
    (See also GitLab!269)
    + Allow # noqa:X123 comments without space between the colon and codes list
    (See also GitLab!273, GitLab#470)
    + Remove broken and unused flake8.listen plugin type
    (See also GitLab!274, GitLab#480)
- Remove pyflakes21.patch which is already included upstream
- Rebase remove_mock_dependency.patch
* Tue Jan 29 2019 tchvatal@suse.com
- Add patch to build with pyflakes-2.1.0:
  * pyflakes21.patch
* Thu Nov  1 2018 arun@gmx.de
- specfile:
  * be more specific in %%files section
  * remove two patches that got included upstream:
    + fix_pycodestyle_240.patch
    + python-flake8-3.5.0-pyflakes-2.0.0.patch
- update to version 3.6.0:
  * New Dependency Information
    + pycodestyle has been updated to >= 2.4.0, < 2.5.0 (See also
    GitLab#381, GitLab#415, GitLab!212, GitLab!230, GitLab!231)
    + Pyflakes has been updated to >= 2.0.0, < 2.1.0 (See also
    GitLab#422, GitLab!239)
    + flake8 requires python 2.x >= 2.7 or python 3.x >= 3.4 (See also
    GitLab!225)
  * Features
    + Add paths to allow local plugins to exist outside of sys.path
    (See also GitLab#379, GitLab!211)
    + Copy setup.cfg files to the temporary git hook execution
    directory (See also GitLab!215)
    + Only skip a file if # flake8: noqa is on a line by itself (See
    also GitLab#453, GitLab!219)
    + Provide a better user experience for broken plugins (See also
    GitLab!221)
    + Report E902 when a file passed on the command line does not
    exist (See also GitLab#405, GitLab!227)
    + Add --extend-ignore for extending the default ignore instead of
    overriding it (See also GitLab#365, GitLab!233)
  * Bugs Fixed
    + Respect a formatter's newline setting when printing (See also
    GitLab!222)
    + Fix leaking of processes in the legacy api (See also GitLab#410,
    GitLab!228)
    + Fix a SyntaxWarning for an invalid escape sequence (See also
    GitLab!244)
    + Fix DeprecationWarning due to import of abc classes from the
    collections module (See also GitLab!249)
    + Defer setuptools import to improve flake8 startup time (See also
    GitLab!250)
    + Fix inconsistent line endings in FileProcessor.lines when
    running under python 3.x (See also GitLab#457, GitLab!255)
* Wed Sep  5 2018 mcepl@suse.com
- Add remove_mock_dependency.patch patch providing independence from the
  external mock package.
* Wed Aug  8 2018 tchvatal@suse.com
- Add patch to build with pyflakes-2.0.x:
  * python-flake8-3.5.0-pyflakes-2.0.0.patch
* Sun Apr 15 2018 sebix+novell.com@sebix.at
- add fix_pycodestyle_240.patch to fix compatibility with pycodestyle
  version 2.4.0. fixes boo#1089438
- use %%license macro for license file
* Thu Jan 11 2018 tchvatal@suse.com
- Fix build with python3 only, add condition for the py2 only deps
* Tue Oct 24 2017 dmueller@suse.com
- update to 3.5.0:
  - Start using new PyCodestyle checks for bare excepts and ambiguous identifier
  drop 0001-Update-pyflakes-range-and-include-doc-links.patch: upstream
* Wed Oct 18 2017 alarrosa@suse.com
- update to 3.4.1
- Add 0001-Update-pyflakes-range-and-include-doc-links.patch from upstream
  in order to allow using pyflakes >= 1.6.0
* Fri Mar 24 2017 jmatejek@suse.com
- update for singlespec
- update to 3.3.0
  * fix setuptools integration
  * drop python 2.6 and python < 3.4 support
  * nonzero exit on problems
  * python 3.6 support
  * performance improvements
- switch requirement from pep8 to pycodestyle
- switch test runner from nose to pytest
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Wed Jan 13 2016 toddrme2178@gmail.com
- Update to 2.5.1
  * Bug Properly look for .flake8 in current working directory
  * Bug Monkey-patch pep8.stdin_get_value to cache the actual value
    in stdin. This helps plugins relying on the function when run
    with multiprocessing.
- Update to 2.5.0
  * Improvement Raise cap on PyFlakes for Python 3.5 support
  * Improvement Avoid deprecation warnings when loading extensions
  * Improvement Separate logic to enable “off-by-default” extensions
  * Bug Properly parse options to setuptools Flake8 command
  * Bug Fix exceptions when output on stdout is truncated before
    Flake8 finishes writing the output
  * Bug Fix error on OS X where Flake8 can no longer acquire or
    create new semaphores
- Update to 2.4.1
  * Bug Do not raise a SystemError unless there were errors in the
    setuptools command.
  * Bug Do not verify dependencies of extensions loaded via
    entry-points.
  * Improvement Blacklist versions of pep8 we know are broken
- Update to 2.4.0
  * Bug Print filenames when using multiprocessing and -q option.
  * Bug Put upper cap on dependencies. The caps for 2.4.0 are:
    > pep8 < 1.6 (Related to GitLab#35)
    > mccabe < 0.4
    > pyflakes < 0.9
  * See also GitLab#32
  * Bug Files excluded in a config file were not being excluded
    when flake8 was run from a git hook.
  * Improvement Print warnings for users who are providing
    mutually exclusive options to flake8.
  * Feature Allow git hook configuration to live in .git/config.
    See the updated VCS hooks docs for more details.
- Remove upstream-included flake8-fix-tests-using-new-mock.patch
- Implement update-alternatives
* Mon Aug 10 2015 mlin@suse.com
- Add upstream patch flake8-fix-tests-using-new-mock.patch
  * Fix tests using mock 1.1.x and above
* Thu Feb 26 2015 tbechtold@suse.com
- update to 2.3.0
  - Add ``--output-file`` option to specify a file to write to
    instead of ``stdout``.
  - Fix interleaving of output while using multiprocessing
  - Flush standard out when using multiprocessing
  - Make the check for "# flake8: noqa" more strict
  - Fix bugs triggered by turning multiprocessing on by default (again)
  - Passing something in via stdin
  - Analyzing a diff
  - Using windows
  - Fix --install-hook when there are no config files present for pep8 or
    flake8.
  - Fix how the setuptools command parses excludes in config files
  - Fix how the git hook determines which files to analyze (Thanks Chris
    Buccella!)
* Mon Sep 15 2014 tbechtold@suse.com
- update to 2.2.3:
  * Actually turn multiprocessing on by default
- Update Requires for pyflakes, pep8 and mccabe
* Thu Jul 10 2014 toddrme2178@gmail.com
- Update to 2.2.2
  - Re-enable multiprocessing by default while fixing the issue
    Windows users were seeing.
- Update to 2.2.1
  - Turn off multiple jobs by default. To enable automatic use
    of all CPUs, use --jobs=auto. Fixes #155 and #154.
* Fri Jun 27 2014 dmueller@suse.com
- update to 2.2.0:
  - New option ``doctests`` to run Pyflakes checks on doctests too
  - New option ``jobs`` to launch multiple jobs in parallel
  - Turn on using multiple jobs by default using the CPU count
  - Add support for ``python -m flake8`` on Python 2.7 and Python 3
  - Fix Git and Mercurial hooks: issues #88, #133, #148 and #149
  - Fix crashes with Python 3.4 by upgrading dependencies
  - Fix traceback when running tests with Python 2.6
  - Fix the setuptools command ``python setup.py flake8`` to read
    the project configuration
* Mon Jan 13 2014 dmueller@suse.com
- update to 2.1.0:
  - Add FLAKE8_LAZY and FLAKE8_IGNORE environment variable support to git and
    mercurial hooks
  - Force git and mercurial hooks to repsect configuration in setup.cfg
  - Only check staged files if that is specified
  - Fix hook file permissions
  - Fix the git hook on python 3
  - Ignore non-python files when running the git hook
  - Ignore .tox directories by default
  - Flake8 now reports the column number for PyFlakes messages
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Apr 24 2013 speilicke@suse.com
- Spec file cleanup
- Run testsuite
- Add LICENSE (for legal)
* Sun Apr 21 2013 dmueller@suse.com
- Initial package (2.0)
